#!/bin/sh

echo "=== Create temporary directory." &&
echo "Creating tmpdir..." &&
if [ -h tmpdir ]
then
  rm -rf tmpdir/*
else
  rm -rf tmpdir &&
  mkdir -p tmpdir/tools
fi

if [ $? -ne 0 ]; then exit 1; fi

echo "=== Build tiny one-process init substitute"
gcc -Os -s sources/system/oneit.c -o tmpdir/oneit || exit 1

# The host system may not have this.

echo "=== Build zlib" &&
tar xvjfC sources/libraries/zlib.tar.bz2 tmpdir &&
cd tmpdir/zlib* &&
# We only need the .a version for static linking squashfs
./configure &&
make &&
cd ../..

if [ $? -ne 0 ]; then exit 1; fi

echo "=== Prepare Linux kernel source code (with squashfs)." &&
tar xvjfC sources/system/linux.tar.bz2 tmpdir &&
cd tmpdir/linux-* &&
# Upgrade to new version (if any).
bzcat ../../sources/system/linux-newversion.bz2 | patch -p1 &&
# Apply patches (if any)
cat ../../sources/system/linux-*patch | patch -p1 &&
echo "=== Add squashfs support to kernel."
tar xvzf ../../sources/system/squashfs.tar.gz &&
cat squashfs*/linux-2.6.13/squashfs*patch | patch -p1 &&
gcc -s -Os -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE \
	squashfs*/squashfs-tools/{mksquashfs.c,read_fs.c,sort.c} \
	-I ../zlib* -I squashfs*/squashfs-tools ../zlib*/libz.a \
	-o ../mksquashfs &&
rm -rf squashfs* &&
cd ../..

if [ $? -ne 0 ]; then exit 1; fi

